// java wrapper for vtkPropCollection object
//

package vtk;
import vtk.*;

public class vtkPropCollection extends vtkCollection
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddItem_2(vtkProp id0);
  public void AddItem(vtkProp id0)
    { AddItem_2(id0); }

  private native long GetNextProp_3();
  public vtkProp GetNextProp() {
    long temp = GetNextProp_3();

    if (temp == 0) return null;
    return (vtkProp)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetLastProp_4();
  public vtkProp GetLastProp() {
    long temp = GetLastProp_4();

    if (temp == 0) return null;
    return (vtkProp)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfPaths_5();
  public int GetNumberOfPaths()
    { return GetNumberOfPaths_5(); }

  public vtkPropCollection() { super(); }

  public vtkPropCollection(long id) { super(id); }
  public native long   VTKInit();

}
